# Changelog for

## Adjust for API changes

- There were various changes in the API of numba, numpy, and pandas.
Chemcoord did not work for too new python versions.
All these deprecation warnings are fixed now.

- There were various changes in the API of sphinx for building the documentation.

## Added Logo
